# Changelog

## Version 0.4.1

* Add support for alternative arXiv URLS
* Always run all redirects on specified urls before choosing provider

## Version 0.4.0

* Refactor code to make it a real Python package
* Rename to ``paper2remarkable``
